@@ -16,6 +16,7 @@ import cftime
 import numpy as np
 import numpy.testing as npt
 import pandas as pd
+import pandas.io.common
 import pint
 from dateutil import parser
 from openscm_units import unit_registry as ur
@@ -107,7 +108,8 @@ def _read_pandas(
     OSError
         Path specified by :obj:`fname` does not exist
     """
-    if not os.path.exists(fname):
+    is_remote = pandas.io.common.is_url(fname)
+    if not is_remote and not os.path.exists(fname):
         raise OSError("no data file `{}` found!".format(fname))
 
     if fname.endswith("xlsx") or fname.endswith("xls"):
@@ -299,6 +301,13 @@ def _from_ts(
     return df, meta
 
 
+def _get_target(run, inplace):
+    if inplace:
+        return run
+    else:
+        return run.copy()
+
+
 class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
     """
     Base class of a data container for timeseries data
@@ -351,7 +360,11 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
             If a string is passed, data will be attempted to be read from file.
             Currently, reading from CSV, gzipped CSV and Excel formatted files is
-            supported.
+            supported. The string could be a URL in a format handled by pandas.
+            Valid URL schemes include http, ftp, s3, gs, and file if pandas>1.2
+            is used. For more information about the remote formats that can be read,
+            see the ``pd.read_csv`` documentation for the version of pandas
+            which is installed.
 
             If no data is provided than an empty :class:`ScmRun <scmdata.run.ScmRun>`
             object is created.
@@ -745,10 +758,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
         KeyError
             If any of the columns do not exist in the meta :class:`DataFrame`
         """
-        if inplace:
-            ret = self
-        else:
-            ret = self.copy()
+        ret = _get_target(self, inplace)
 
         if isinstance(columns, str):
             columns = [columns]
@@ -1881,11 +1891,7 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
             ``"unit_context"`` is already included in ``self``'s :meth:`meta_attributes`
             and it does not match ``context`` for the variables to be converted.
         """
-        # pylint: disable=protected-access
-        if inplace:
-            ret = self
-        else:
-            ret = self.copy()
+        ret = _get_target(self, inplace)
 
         to_convert_filtered = ret.filter(**kwargs, log_if_empty=False)
         to_not_convert_filtered = ret.filter(**kwargs, keep=False, log_if_empty=False)
@@ -2200,6 +2206,45 @@ class BaseScmRun(OpsMixin):  # pylint: disable=too-many-public-methods
 
             return type(self)(data, index=index, columns=meta)
 
+    def round(self, decimals=3, inplace=False):
+        """
+        Round data to a given number of decimal places.
+
+        For values exactly halfway between rounded decimal values, NumPy rounds
+        to the nearest even value. Thus 1.5 and 2.5 round to 2.0, -0.5 and 0.5
+        round to 0.0, etc.
+
+        Parameters
+        ----------
+        decimals : int
+            Number of decimal places to round each value to.
+
+        inplace : bool
+            If True, apply the conversion inplace and return None
+
+        Returns
+        -------
+        :class:`ScmRun <scmdata.run.ScmRun>`
+            If :obj:`inplace` is not ``False``, a new :class:`ScmRun <scmdata.run.ScmRun>` instance
+            with the rounded values.
+
+        """
+        ret = _get_target(self, inplace)
+
+        # Check if any values are smaller than half the smallest step
+        # They may be rounded down to zero
+        min_value = ret._df.abs().min().min()
+        if min_value <= 0.5 * 10 ** -decimals:
+            warnings.warn(
+                "There are small values which may be truncated during rounding. Either increase the number"
+                "of decimals or convert the units of the timeseries so that the quantities are larger."
+            )
+
+        ret._df = ret._df.round(decimals)
+
+        if not inplace:
+            return ret
+
 
 def _merge_metadata(metadata):
     res = metadata[0].copy()
